@@ -20,25 +20,22 @@ class NoBridgeError(Exception):
 class SshClient():
     """Helper class for a SSH client.  User is responsible for retry/errors."""
 
-    write_data = None
-
-    def __init__(
-        self,
-        host,
-        port=None,
-        username=None,
-        password=None,
-        tunnel=None,
-        init_wait=0,
-        verbose=0,
-    ):
-        self.record = {} if self.write_data else None
+    def __init__(self,
+                 host,
+                 port=None,
+                 username=None,
+                 password=None,
+                 tunnel=None,
+                 init_wait=0,
+                 verbose=0,
+                 record=False):
         self.host = host
         self.port = port or 22
         self.username = username
         self.password = password
         self.init_wait = init_wait
         self._tun = tunnel
+        self.record = [] if record else None
 
         self.verbose = verbose
         self._conn = None
@@ -114,8 +111,6 @@ class SshClient():
             r = r[:-11]
         if self.verbose > 2:
             print('#!<{}'.format(r))
-        if self.record is not None:
-            self.record[cmd_bckd] = r
         return r
 
     async def scmd(self, cmd, timeout=5.0):
@@ -124,7 +119,7 @@ class SshClient():
             await self._open()
         r = await self._conn.run(cmd, timeout=timeout)
         if self.record is not None:
-            self.record[cmd] = r.stdout
+            self.record.append([cmd, r.stdout])
         return r.stdout
 
     async def get_brmacs(self, br_name):
